@@ -1,4 +1,5 @@
 from pyspark.sql import DataFrame as SparkDF
+from pyspark.sql.types import Row as SparkRow
 from pandas import DataFrame as PandasDF
 
 from multiprocessing.pool import ThreadPool
@@ -35,8 +36,8 @@ def concat_spark_columns(data, name='concat_column', sep='|', return_data=False)
 
 	@f.udf(StringType())
 	def _to_string(x):
-		if isinstance(x, dict):
-			x = dict(x)
+		if isinstance(x, SparkRow):
+			x = x.asDict(recursive=True)
 		return x if isinstance(x, str) else str(x).lower()
 
 	data = data.withColumn(name, f.concat_ws(sep, *[_to_string(col) for col in data.columns]))
